function [out] = GK15(M,R,VS30,F,Q_0,Bdepth,flag)
% 2015 GRAIZER-KALKAN Ground Motion Prediction Equation (GMPE)
%
%   Syntax:
%           out = GK15(M, R, VS30, F, Q_0, Bdepth, flag)
%
%   Input:
%           M      = Moment magnitude
%           R      = Closest distance to fault rupture in km (i.e., Rrup)
%           VS30   = Average shear-wave velocity in the upper 30 m in m/s
%           Bdepth = Depth to 1,500 m/s shear-wave velocity (i.e., Z1.5)
%                    Bdepth = 0 for non-basin sites
%           F      = Style of faulting
%                    F = 1.0 for strike-slip and normal faulting
%                    F = 1.28 for reverse faulting 
%                    F = 1.14 for combination of strike-slip and reverse faulting
%           Q_0    = Regional Q_0 value (e.g., 150 for California; 50 for Napa)
%           Bdepth = Depth to 1,500 m/s shear-wave velocity to define basin (i.e., Z1.5)
%                    Bdepth = 0 for non-basin sites 
%           flag   = 'm' for maximum horizontal randomly oriented component 
%                    'a' for average horizontal randomly oriented component
%   Output:
%           out    = [t,SA,sigma]
%           t      = Spectral period vector (PGA to 5 s)
%           SA     = Median pseudospectral acceleration ordinates (PGA to SA at 5 s)
%           Sigma  = Total standard deviations
%
%   $Revision: 1.0 $  $Date: 04/10/2015 $
%   Written by Dr. Erol Kalkan, P.E. (ekalkan@usgs.gov)
%
%   Comment blocks and equation references in this function correspond to the
%   following publications:
%
%   Graizer, V. and Kalkan, E. (2016). "Summary of GK15 Ground-Motion
%   Prediction Equation for Predicting PGA and 5%-Damped SA from Shallow
%   Crustal Continental Earthquakes", Bulletin of Seismological Society of
%   America, 106(2): 687-707, doi: 10.1785/0120150194.
%
%   Graizer, V. and Kalkan, E. (2015). Update of the Graizer-Kalkan ground-motion
%   prediction equation for shallow crustal continental earthquakes:
%   U.S. Geological Survey Open-File Report 2015-1009, p. 79.
%   http://pubs.usgs.gov/of/2015/1009/
%
%   THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS ?AS IS" AND ANY EXPRESS 
%   OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED 
%   WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR 
%   PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER BE LIABLE   
%   FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR 
%   CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, 
%   PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR 
%   PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF 
%   LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING 
%   NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS 
%   SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
if flag == 'm'; amp = 1; else 
    amp = 1/1.12;                 % average to maximum component conversion
end
%% GMPE for PGA (GK15PGA)
c1  =  0.14;
c2  = -6.25;
c3  =  0.37;
c4  =  2.237;
c5  = -7.542;
c6  = -0.125;
c7  =  1.19;
c8  = -6.15;
c9  =  0.6;
c10 =  0.345;
bv  = -0.24;
VA  = 484.5;

% InPGA = G1 + G2 + G3 + G4 + G5;
G1 = log(( c1 * atan (M + c2) + c3) * F);
Ro = c4*M + c5;
Do = c6 * cos(c7 * (M + c8)) + c9;
G2 = -0.5 * log((1-R/Ro)^2 + 4 * (Do^2) * (R/Ro));
G3 = -c10 * R / Q_0;
G4 = bv * log(VS30 / VA);
A_Bdepth = 1.077/sqrt((1-(1.5/(Bdepth+0.1))^2)^2+4*0.7^2*(1.5/(Bdepth+0.1))^2);
A_Bdist = 1/sqrt((1-(40/(R+0.1))^2)^2+4*0.7^2*(40/(R+0.1))^2);
G5 = log(1 + A_Bdepth * A_Bdist);
InPGA = G1 + G2 + G3 + G4 + G5;
PGA = exp(InPGA) * amp;

%% GMPE for Spectral Shape (GK15SS)
t = [0.01   0.02    0.022   0.025   0.029   0.03    0.032   0.035   ...
    0.036   0.04    0.042   0.044   0.045   0.046   0.048   0.05    ...
    0.055   0.06    0.065   0.067   0.07    0.075   0.08    0.085   ...
    0.09    0.095   0.1 0.11    0.12    0.13    0.133   0.14    0.15 ...
    0.16    0.17    0.18    0.19    0.2 0.22    0.24    0.25    0.26 ...
    0.28    0.29    0.3 0.32    0.34    0.35    0.36    0.38    0.4 ...
    0.42    0.44    0.45    0.46    0.48    0.5 0.55    0.6 0.65    ...
    0.667   0.7 0.75    0.8 0.85    0.9 0.95    1   1.1 1.2 1.3 1.4 ...
    1.5 1.6 1.7 1.8 1.9 2   2.2 2.4 2.5 2.6 2.8 3   3.2 3.4 3.5 3.6 ...
    3.8 4   4.2 4.4 4.6 4.8 5];

m1 = -0.0012;
m2 = -0.38;
m3 = 0.0006;
m4 = 3.9;
a1 = 0.01686;
a2 = 1.2695;
a3 = 0.0001;
Dsp = 0.75;
t1 = 0.001;
t2 = 0.59;
t3 = -0.0005;
t4 = -2.3;
s1 = 0.001;
s2 = 0.077;
s3 = 0.3251;

if (M<5.5); M=5.5; end

for j = 1:length(t);
    I = (a1*M+a2)*exp(a3*R);
    mu = m1*R + m2*M + m3*VS30 + m4;
    S = s1*R - (s2*M + s3);
    Tsp_o = max(0.3,abs(t1*R + t2*M + t3*VS30 + t4));
    zay = 1.763-0.25*atan(1.4*(Bdepth-1));
    
    F1(j) = I*exp(-0.5*((log(t(j))+mu)/S)^2);
    F2(j) = 1/sqrt((1-(t(j)/Tsp_o)^zay)^2 + 4*Dsp^2*(t(j)/Tsp_o)^zay);
    Y(j) = F1(j) + F2(j);
end
Sigma = max(0.668 + 0.0047 * log(t),0.8 + 0.13 * log(t));

%% SA = GK15SS x exp(GK15PGA)
SA  = [PGA Y * exp(InPGA) * amp];
t = [0 t];
Sigma = [0.66 Sigma];

%% Output [Spectral Period, SA in "g"]
out = [t' SA' Sigma'];
return

