%  RUN GRAIZER-KALKAN (GK15) GMPE TO GENERATE 5% DAMPED PSEUDOSPECTRAL 
%  ACCELERATION RESPONSE SPECTRUM
%
%   Syntax:
%           runGK15
%
%   Input:
%           M      = Moment magnitude
%           R      = Closest distance to fault rupture in km (i.e., Rrup)
%           VS30   = Average shear-wave velocity in the upper 30 m in m/s
%           Bdepth = Depth to 1,500 m/s shear-wave velocity isosurface (i.e., Z1.5)
%                    Bdepth = 0 for non-basin sites
%
%           F      = Style of faulting
%                    F = 1.0 for strike-slip and normal faulting,
%                    F = 1.28 for reverse faulting, and
%                    F = 1.14 for combination of strike-slip and reverse faulting
%   Output:
%           SA       = Median pseudospectral acceleration (SA) ordinates (PGA to 5 s)
%           SA_16    = 16th percentile SA
%           SA_84    = 84th percentile SA
%
%   $Revision: 1.0 $  $Date: 04/10/2015 $
%   Written by Dr. Erol Kalkan, P.E. (ekalkan@usgs.gov)
%
%   Comment blocks and equation references in this function correspond to the
%   following publications:
%
%   Graizer, V. and Kalkan, E. (2016). "Summary of GK15 Ground-Motion
%   Prediction Equation for Predicting PGA and 5%-Damped SA from Shallow
%   Crustal Continental Earthquakes", Bulletin of Seismological Society of
%   America, 106(2): 687-707, doi: 10.1785/0120150194.
%
%   Graizer, V. and Kalkan, E. (2015). Update of the Graizer-Kalkan ground-motion
%   prediction equation for shallow crustal continental earthquakes,
%   U.S. Geological Survey Open-File Report 2015-1009, p. 79. available at
%   http://pubs.usgs.gov/of/2015/1009/
%
%   THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS "AS IS" AND ANY EXPRESS 
%   OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED 
%   WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR 
%   PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER BE LIABLE   
%   FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR 
%   CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, 
%   PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR 
%   PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF 
%   LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING 
%   NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS 
%   SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
clear all; clc; close all;
flag = input('maximum or average component (enter m or a): ', 's');

%% Input parameters
M      = 6.0;
R      = 4.4;
VS30   = 350;
F      = 1.0;  % strike-slip fault
Bdepth = 0;    % no basin
Q_0    = 150;  % regional quality factor (e.g., 150 for California)

%% Call GK15
[out] = GK15(M,R,VS30,F,Q_0,Bdepth,flag);
t = out(:,1);
SA = out(:,2);
Sigma = out(:,3);

%% SA plus/minus sigma (16th and 84th percentile values)
SA_16 = SA./exp(Sigma);
SA_84 = SA.*exp(Sigma);

PeakSaAmp = max(SA);

for j = 1:length(t);
    if (SA(j) == PeakSaAmp); Tmax = t(j); break; end
end

%% Plot spectrum
figure
fsz = 16;
set(gcf,'position',[300 283 600 400]);
set(gca,'TickLength',[.0025 .0025]);
set(gca,'fontname','times','fontsize',fsz);

loglog(t,SA,'r-','LineWidth',2.5); hold;
loglog(t,SA_16,'k--','LineWidth',1.0);
h = legend('SA','+/- \sigma','Location','NE','Orientation','Horizontal');
set(h,'fontname','times','EdgeColor',[0.5 0.5 0.5]);

loglog(t,SA_84,'k--','LineWidth',1.0);
loglog(0.01,SA(1),'o','MarkerSize',13,...
    'MarkerEdgeColor','b','MarkerFaceColor','r');
loglog(Tmax,0.001,'o','MarkerSize',13,...
    'MarkerEdgeColor','b','MarkerFaceColor','r');
loglog(Tmax,PeakSaAmp,'o','MarkerSize',13,...
    'MarkerEdgeColor','b','MarkerFaceColor','r');

axis([0.01 5 0.01 4]);
set(gca,'XTickLabel',{'0.01','0.1','1','5'},'fontsize',fsz,'fontname','times');
set(gca,'YTickLabel',{'0.01','0.1','1','4'},'fontsize',fsz,'fontname','times');
xlabel('Period, s','FontSize',[fsz],'fontname','times');
ylabel('Pseudospectral acceleration, g','FontSize',[fsz],'fontname','times');

t1 = strcat('{M_w = }',num2str(M,'%5.1f'));
t2 = strcat('{R = }',num2str(R),' km');
t3 = strcat('{V_S_3_0 = }',num2str(VS30),' m/s');

text('pos',[0.015 0.045],'str',t1,'Color','k','FontSize',[fsz],'FontWeight','normal','BackgroundColor','w');
text('pos',[0.015 0.03],'str',t2,'Color','k','FontSize',[fsz],'FontWeight','normal','BackgroundColor','w');
text('pos',[0.015 0.018],'str',t3,'Color','k','FontSize',[fsz],'FontWeight','normal','BackgroundColor','w');

t4 = strcat(num2str(SA(1),'%5.2f'), {' g'});
t5 = strcat(num2str(PeakSaAmp,'%5.2f'),{' g @ '},num2str(Tmax), {' s'});

text('pos',[0.012 SA(1)*0.8],'str',t4,'Color','k','FontSize',[fsz],'FontWeight','normal','BackgroundColor','w');
text('pos',[Tmax PeakSaAmp*1.4],'str',t5,'Color','k','FontSize',[fsz],'FontWeight','normal','BackgroundColor','w');

title('Pseudospectral Acceleration Response Spectrum (5% damped)','FontSize',[fsz+1],'fontname','times');
set(gca,'Xtick',[0.01 0.1 1 5]);
set(gca,'XTickLabel',{'0.01','0.1','1','5'},'fontsize',fsz,'fontname','times');
hold on; grid on;